@@ -496,11 +496,14 @@ class Application(Router):
         await self.stop()
 
         # re-raise any errors so we can validate during tests
-        for task in done | pending:
+        for task in done:
             exc = task.exception()
             if exc is not None:
                 raise exc
 
+        for task in pending:
+            task.cancel()
+
         return consumed
 
     def consume_forever(self) -> Awaitable:
